==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/plugin/lang/bg/lang.php <==
<?php
/**
 * bulgarian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
 * @author Viktor Usunov <usun0v@mail.bg>
 * @author Kiril <neohidra@gmail.com>
 */
$lang['menu']                  = 'Управление на приставките';
$lang['download']              = 'Сваляне и инсталиране на нова приставка';
$lang['manage']                = 'Инсталирани приставки';
$lang['btn_info']              = 'информация';
$lang['btn_update']            = 'обновяване';
$lang['btn_delete']            = 'изтриване';
$lang['btn_settings']          = 'настройки';
$lang['btn_download']          = 'Сваляне';
$lang['btn_enable']            = 'Запис';
$lang['url']                   = 'URL';
$lang['installed']             = 'Инсталирана:';
$lang['lastupdate']            = 'Актуализирана:';
$lang['source']                = 'Източник:';
$lang['unknown']               = 'непознат';
$lang['updating']              = 'Актуализиране ...';
$lang['updated']               = 'Приставката %s е качена успешно';
$lang['updates']               = 'Следните приставки са актуализирани успешно';
$lang['update_none']           = 'Не са намерени нови версии.';
$lang['deleting']              = 'Изтриване ...';
$lang['deleted']               = 'Приставката %s е изтрита успешно.';
$lang['downloading']           = 'Сваляне ...';
$lang['downloaded']            = 'Приставката %s е инсталирана успешно  ';
$lang['downloads']             = 'Следните приставки са инсталирани успешно:';
$lang['download_none']         = 'Не са намерени приставки или е възникнала непозната грешка при свалянето и инсталирането.';
$lang['plugin']                = 'Приставка:';
$lang['components']            = 'Компоненти';
$lang['noinfo']                = 'Приставка не върна информация, може да е повредена.';
$lang['name']                  = 'Име:';
$lang['date']                  = 'Дата:';
$lang['type']                  = 'Тип:';
$lang['desc']                  = 'Описание:';
$lang['author']                = 'Автор:';
$lang['www']                   = 'Уебстраница:';
$lang['error']                 = 'Възникна непозната грешка.';
$lang['error_download']        = 'Свалянето на приставката %s е невъзможно.';
$lang['error_badurl']          = 'Предполагаем грешен адрес - не може да се определи име на файла от URL адреса';
$lang['error_dircreate']       = 'Създаването на временна директория за сваляне не е възможно.';
$lang['error_decompress']      = 'Разархивирането на сваленият файл е невъзможно. Вероятно е резултат от грешка при свалянето, в този случай трябва да опитате отново; или формата на компресия е непознат - тогава трябва да свалите и инсталирате приставката ръчно.';
$lang['error_copy']            = 'Възникна грешка при копиране на файл по време на инсталиране на приставката <em>%s</em>: вероятно дискът е пълен или правата за достъп до файловете са грешни. Може да доведе до частично инсталирана приставка и да причини нестабилно функциониране на wiki-то ви.';
$lang['error_delete']          = 'Възникна грешка при изтриването на приставката <em>%s</em>.  Най-вероятната причина е в правата за достъп до файл или директория';
$lang['enabled']               = 'Приставката %s е включена.';
$lang['notenabled']            = 'Приставката %s не може да бъде включена, моля проверете правата за файловете.';
$lang['disabled']              = 'Приставката %s е изключена.';
$lang['notdisabled']           = 'Приставката %s не е изключена, моля проверете правата за файловете.';
$lang['packageinstalled']      = 'Пакетът е инсталиран успешно (%d приставка%s: %s).';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/bg/lang.php <==
<?php
/**
 * bulgarian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
 * @author Viktor Usunov <usun0v@mail.bg>
 * @author Kiril <neohidra@gmail.com>
 */
$lang['menu']                  = 'Управление на приставките';
$lang['download']              = 'Сваляне и инсталиране на нова приставка';
$lang['manage']                = 'Инсталирани приставки';
$lang['btn_info']              = 'информация';
$lang['btn_update']            = 'обновяване';
$lang['btn_delete']            = 'изтриване';
$lang['btn_settings']          = 'настройки';
$lang['btn_download']          = 'Сваляне';
$lang['btn_enable']            = 'Запис';
$lang['url']                   = 'URL';
$lang['installed']             = 'Инсталирана:';
$lang['lastupdate']            = 'Актуализирана:';
$lang['source']                = 'Източник:';
$lang['unknown']               = 'непознат';
$lang['updating']              = 'Актуализиране ...';
$lang['updated']               = 'Приставката %s е качена успешно';
$lang['updates']               = 'Следните приставки са актуализирани успешно';
$lang['update_none']           = 'Не са намерени нови версии.';
$lang['deleting']              = 'Изтриване ...';
$lang['deleted']               = 'Приставката %s е изтрита успешно.';
$lang['downloading']           = 'Сваляне ...';
$lang['downloaded']            = 'Приставката %s е инсталирана успешно  ';
$lang['downloads']             = 'Следните приставки са инсталирани успешно:';
$lang['download_none']         = 'Не са намерени приставки или е възникнала непозната грешка при свалянето и инсталирането.';
$lang['plugin']                = 'Приставка:';
$lang['components']            = 'Компоненти';
$lang['noinfo']                = 'Приставка не върна информация, може да е повредена.';
$lang['name']                  = 'Име:';
$lang['date']                  = 'Дата:';
$lang['type']                  = 'Тип:';
$lang['desc']                  = 'Описание:';
$lang['author']                = 'Автор:';
$lang['www']                   = 'Уебстраница:';
$lang['error']                 = 'Възникна непозната грешка.';
$lang['error_download']        = 'Свалянето на приставката %s е невъзможно.';
$lang['error_badurl']          = 'Предполагаем грешен адрес - не може да се определи име на файла от URL адреса';
$lang['error_dircreate']       = 'Създаването на временна директория за сваляне не е възможно.';
$lang['error_decompress']      = 'Разархивирането на сваленият файл е невъзможно. Вероятно е резултат от грешка при свалянето, в този случай трябва да опитате отново; или формата на компресия е непознат - тогава трябва да свалите и инсталирате приставката ръчно.';
$lang['error_copy']            = 'Възникна грешка при копиране на файл по време на инсталиране на приставката <em>%s</em>: вероятно дискът е пълен или правата за достъп до файловете са грешни. Може да доведе до частично инсталирана приставка и да причини нестабилно функциониране на wiki-то ви.';
$lang['error_delete']          = 'Възникна грешка при изтриването на приставката <em>%s</em>.  Най-вероятната причина е в правата за достъп до файл или директория';
$lang['enabled']               = 'Приставката %s е включена.';
$lang['notenabled']            = 'Приставката %s не може да бъде включена, моля проверете правата за файловете.';
$lang['disabled']              = 'Приставката %s е изключена.';
$lang['notdisabled']           = 'Приставката %s не е изключена, моля проверете правата за файловете.';
$lang['packageinstalled']      = 'Пакетът е инсталиран успешно (%d приставка: %s).';
